/*
    dataretriever.cpp
    SPDX-FileCopyrightText: 2001, 2002, 2003 Frerich Raabe <raabe@kde.org>

    SPDX-License-Identifier: BSD-2-Clause
*/

#include "dataretriever.h"

namespace Syndication
{
DataRetriever::DataRetriever()
{
}

DataRetriever::~DataRetriever()
{
}

} // namespace Syndication

#include "moc_dataretriever.cpp"
