/*
    This file is part of the syndication library
    SPDX-FileCopyrightText: 2006 Frank Osterfeld <osterfeld@kde.org>

    SPDX-License-Identifier: LGPL-2.0-or-later
*/

#include "specificitem.h"

namespace Syndication
{
SpecificItem::~SpecificItem()
{
}

} // namespace Syndication
