/*
    This file is part of the syndication library
    SPDX-FileCopyrightText: 2005 Frank Osterfeld <osterfeld@kde.org>

    SPDX-License-Identifier: LGPL-2.0-or-later
*/

#ifndef SYNDICATION_RSS2_RSS2_H
#define SYNDICATION_RSS2_RSS2_H

#include <syndication/rss2/category.h>
#include <syndication/rss2/cloud.h>
#include <syndication/rss2/document.h>
#include <syndication/rss2/enclosure.h>
#include <syndication/rss2/image.h>
#include <syndication/rss2/item.h>
#include <syndication/rss2/parser.h>
#include <syndication/rss2/source.h>
#include <syndication/rss2/textinput.h>

namespace Syndication
{
/**
 * A parser and model classes for RSS 0.91 (Userland and Netscape flavor), 0.92, 0.93, 0.94
 * and 2.0(.1)
 */
namespace RSS2
{
}

} // namespace Syndication

#endif // SYNDICATION_RSS2_RSS2_H
